import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear, max } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/dralmadani/c04f95746e2f36b040d3d764ab7b9c62/raw/0ac9460c0bce221efb38a8a75beeb00d6c315023/LargestCitiesPopulation2020USwithLongitude_Latitude.csv';

const width = 500;
const height = 500;

const App = () => {
  const [data, setData] = useState(null);
  useEffect(() => {
    const row = (d) => {
      d.latitude = +d['latitude'];
      //d["longitude"] = +d["longitude"];
      //if(d.longitude > 0) {
      d['longitude'] = +d['longitude'] * -1;
      //}

      d.pop2020 = +d.pop2020;
      d.pop2010 = +d.pop2010;
      return d;
    };
    //then (setData)
    csv(csvUrl, row).then(data =>{setData(data.slice(0,20))});//(setData);//(data =>{setData(data.slice(0,10))});
  }, []);
  /*
  useEffect(() => {
    csv(csvUrl, row).then(setData);
  }, []);
*/
  if (!data) {
    return <pre>Loading...</pre>;
  }
  console.log(data[0]);

  const xScale = scaleBand()
    .domain(data.map((d) => d.City))
    .range([0, width]);

  const yScale = scaleLinear()
    .domain([0, max(data, (d) => d.pop2020)])
    .range([0, height]);

  
  return (
    <svg width={width} height={height}>
      {data.map((d) => (
        <rect
          x={xScale(d.City)}
          y={0}
          width={xScale.bandwidth()}
          height={yScale(d.pop2020)}
        />
      ))}
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);

// To compute the arcs manually (without d3.pie):
// data.map((d, i) => (
//   <path
//     fill={d['RGB hex value']}
//     d={pieArc({
//       startAngle: (i / data.length) * 2 * Math.PI,
//       endAngle: ((i + 1) / data.length) * 2 * Math.PI
//     })}
//   />
// ))
